@@ -14,12 +14,12 @@ import os
 import shutil
 from pathlib import Path
 
+from gi.repository import Adw
 from gi.repository import Gdk
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
 from nbxmpp import JID
-from nbxmpp.types import BlockingReportValues
 
 from gajim.common import app
 from gajim.common import events
@@ -43,19 +43,19 @@ from gajim.common.util.uri import open_uri
 from gajim.common.util.uri import show_in_folder
 from gajim.common.util.uri import XmppIri
 
-from gajim.gtk.account_side_bar import AccountSideBar
-from gajim.gtk.activity_side_bar import ActivitySideBar
-from gajim.gtk.builder import get_builder
+from gajim.gtk.about import AboutDialog
+from gajim.gtk.alert import AlertDialog
+from gajim.gtk.alert import CancelDialogResponse
+from gajim.gtk.alert import ConfirmationAlertDialog
+from gajim.gtk.alert import DialogEntry
+from gajim.gtk.alert import DialogResponse
+from gajim.gtk.alert import InformationAlertDialog
+from gajim.gtk.app_side_bar import AppSideBar
 from gajim.gtk.chat_list import ChatList
 from gajim.gtk.chat_list_row import ChatListRow
 from gajim.gtk.chat_stack import ChatStack
 from gajim.gtk.const import MAIN_WIN_ACTIONS
-from gajim.gtk.dialogs import ConfirmationDialog
-from gajim.gtk.dialogs import DialogButton
-from gajim.gtk.dialogs import InputDialog
-from gajim.gtk.dialogs import SimpleDialog
 from gajim.gtk.emoji_chooser import EmojiChooser
-from gajim.gtk.main_menu_button import MainMenuButton
 from gajim.gtk.main_stack import MainStack
 from gajim.gtk.start_chat import parse_uri
 from gajim.gtk.structs import AccountJidParam
@@ -67,10 +67,10 @@ from gajim.gtk.structs import ModerateAllMessagesParam
 from gajim.gtk.structs import ModerateMessageParam
 from gajim.gtk.structs import OccupantParam
 from gajim.gtk.structs import RetractMessageParam
+from gajim.gtk.util.misc import get_ui_string
 from gajim.gtk.util.window import get_app_window
 from gajim.gtk.util.window import open_window
 from gajim.gtk.util.window import resize_window
-from gajim.gtk.workspace_side_bar import WorkspaceSideBar
 
 if TYPE_CHECKING:
     from gajim.gtk.control import ChatControl
@@ -78,46 +78,53 @@ if TYPE_CHECKING:
 if app.is_display(Display.X11):
     from gi.repository import GdkX11
 
+if app.is_display(Display.WIN32):
+    import gi
+
+    gi.require_version("GdkWin32", "4.0")
+    from gi.repository import GdkWin32
+
 log = logging.getLogger("gajim.gtk.main")
 
 
-class MainWindow(Gtk.ApplicationWindow, EventHelper):
+@Gtk.Template(string=get_ui_string("main.ui"))
+class MainWindow(Adw.ApplicationWindow, EventHelper):
+    __gtype_name__ = "MainWindow"
+
+    _header_bar: Adw.HeaderBar = Gtk.Template.Child()
+    _app_side_bar: AppSideBar = Gtk.Template.Child()
+    _main_stack: MainStack = Gtk.Template.Child()
+
     def __init__(self) -> None:
-        Gtk.ApplicationWindow.__init__(self)
+        app.window = self
+
+        Adw.ApplicationWindow.__init__(self)
         EventHelper.__init__(self)
+
         self.set_application(app.app)
         self.set_title(GLib.get_application_name())
         self.set_default_icon_name("gajim")
 
-        app.window = self
+        self._startup_finished: bool = False
+
+        self._emoji_chooser: EmojiChooser | None = None
+        self._about_dialog = None
+        self._chat_page = self._main_stack.get_chat_page()
+
+        self._prepare_window()
+
+    def init(self) -> None:
+        """Init is called at a later point, so that the (empty) window can be
+        displayed early, indicating a progressing Gajim startup.
+        """
+        self._about_dialog = AboutDialog()
 
         self._add_actions()
+        self._add_settings_actions()
         self._add_stateful_actions()
         self._connect_actions()
 
-        self._startup_finished: bool = False
-
-        self._ui = get_builder("main.ui")
-
-        self.set_child(self._ui.main_grid)
-
-        self._emoji_chooser: EmojiChooser | None = None
-
-        self._main_stack = MainStack()
-        self._ui.main_grid.attach(self._main_stack, 1, 0, 1, 1)
-
-        self._chat_page = self._main_stack.get_chat_page()
-
-        self._ui.left_grid.attach(MainMenuButton(), 0, 0, 1, 1)
-
-        self._activity_side_bar = ActivitySideBar(self._chat_page)
-        self._ui.activity_box.prepend(self._activity_side_bar)
-
-        self._workspace_side_bar = WorkspaceSideBar(self._chat_page)
-        self._ui.workspace_scrolled.set_child(self._workspace_side_bar)
-
-        self._account_side_bar = AccountSideBar()
-        self._ui.account_box.append(self._account_side_bar)
+        self._app_side_bar.set_chat_page(self._chat_page)
 
         self.connect("notify::is-active", self._on_window_active)
         self.connect("close-request", self._on_close_request)
@@ -157,12 +164,11 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         self._load_chats()
         self._load_unread_counts()
 
-        self._prepare_window()
+        app.ged.raise_event(events.RegisterActions())
 
         chat_list_stack = self._chat_page.get_chat_list_stack()
         app.app.systray.connect_unread_widget(chat_list_stack, "unread-count-changed")
-
-        self.set_show_menubar(app.settings.get_app_setting("show_main_menu"))
+        chat_list_stack.connect("chat-selected", self._on_chat_selected)
 
         for client in app.get_clients():
             client.connect_signal("state-changed", self._on_client_state_changed)
@@ -170,11 +176,21 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                 "resume-successful", self._on_client_resume_successful
             )
 
+    @property
+    def about_dialog(self) -> AboutDialog:
+        assert self._about_dialog is not None
+        return self._about_dialog
+
     def get_action(self, name: str) -> Gio.SimpleAction:
         action = self.lookup_action(name)
         assert isinstance(action, Gio.SimpleAction)
         return action
 
+    def set_action_state(self, name: str, value: bool) -> None:
+        action = self.lookup_action(name)
+        assert action is not None
+        action.change_state(GLib.Variant("b", value))
+
     def get_chat_stack(self) -> ChatStack:
         return self._chat_page.get_chat_stack()
 
@@ -198,14 +214,15 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         toplevel.set_skip_taskbar_hint(value)
 
     def set_urgency_hint(self, value: bool) -> None:
-        if not app.is_display(Display.X11):
-            return
-
         if not app.settings.get("use_urgency_hint"):
             return
 
-        toplevel = cast(GdkX11.X11Surface, self.get_surface())
-        toplevel.set_urgency_hint(value)
+        if app.is_display(Display.X11):
+            toplevel = cast(GdkX11.X11Surface, self.get_surface())
+            toplevel.set_urgency_hint(value)
+        elif app.is_display(Display.WIN32):
+            toplevel = cast(GdkWin32.Win32Surface, self.get_surface())
+            toplevel.set_urgency_hint(value)
 
     def mark_workspace_as_read(self, workspace: str) -> None:
         chat_list_stack = self._chat_page.get_chat_list_stack()
@@ -247,7 +264,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         client.connect_signal("resume-successful", self._on_client_resume_successful)
 
     def _on_account_disabled(self, event: events.AccountDisabled) -> None:
-        workspace_id = self._workspace_side_bar.get_first_workspace()
+        workspace_id = self._app_side_bar.get_first_workspace()
         self.activate_workspace(workspace_id)
         self._main_stack.remove_account_page(event.account)
         self._main_stack.remove_chats_for_account(event.account)
@@ -289,7 +306,14 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
 
     @staticmethod
     def _on_plain_connection(event: events.PlainConnection) -> None:
-        ConfirmationDialog(
+
+        def _on_response(response_id: str) -> None:
+            if response_id == "connect":
+                event.connect()
+            else:
+                event.abort()
+
+        AlertDialog(
             _("Insecure Connection"),
             _(
                 "You are about to connect to the account %(account)s "
@@ -303,12 +327,13 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                     event.account, prefer_custom=True
                 ),
             },
-            [
-                DialogButton.make("Cancel", text=_("_Abort"), callback=event.abort),
-                DialogButton.make(
-                    "Remove", text=_("_Connect Anyway"), callback=event.connect
+            responses=[
+                CancelDialogResponse(label=_("_Abort")),
+                DialogResponse(
+                    "connect", _("_Connect Anyway"), appearance="destructive"
                 ),
             ],
+            callback=_on_response,
         )
 
     @staticmethod
@@ -317,9 +342,9 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
 
     @staticmethod
     def _on_http_auth(event: events.HttpAuth) -> None:
-        def _response(answer: str) -> None:
+        def _on_response(response_id: str) -> None:
             event.client.get_module("HTTPAuth").build_http_auth_answer(
-                event.stanza, answer
+                event.stanza, "yes" if response_id == "accept" else "no"
             )
 
         account = event.client.account
@@ -335,15 +360,14 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             sec_msg = event.data.body + "\n" + sec_msg
         message = message + "\n" + sec_msg
 
-        ConfirmationDialog(
+        AlertDialog(
             _("HTTP Authorization Request"),
             message,
-            [
-                DialogButton.make(
-                    "Cancel", text=_("_No"), callback=_response, args=["no"]
-                ),
-                DialogButton.make("Accept", callback=_response, args=["yes"]),
+            responses=[
+                CancelDialogResponse(label=_("_No")),
+                DialogResponse("accept", _("_Accept")),
             ],
+            callback=_on_response,
         )
 
     def _on_muc_added(self, event: events.MucAdded) -> None:
@@ -374,6 +398,11 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             act.set_enabled(enabled)
             self.add_action(act)
 
+    def _add_settings_actions(self) -> None:
+        action = app.settings.create_action("show_header_bar")
+        action.simple_bind_property(self._header_bar, "visible")
+        self.add_action(action)
+
     def _add_stateful_actions(self) -> None:
         action = Gio.SimpleAction.new_stateful(
             "set-encryption", GLib.VariantType("s"), GLib.Variant("s", "disabled")
@@ -381,6 +410,12 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
 
         self.add_action(action)
 
+        action = Gio.SimpleAction.new_stateful(
+            "chat-list-visible", None, GLib.Variant("b", True)
+        )
+
+        self.add_action(action)
+
     def _connect_actions(self) -> None:
         actions = [
             ("change-nickname", self._on_action),
@@ -413,8 +448,6 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             ("increase-app-font-size", self._on_app_font_size_action),
             ("decrease-app-font-size", self._on_app_font_size_action),
             ("reset-app-font-size", self._on_app_font_size_action),
-            ("toggle-chat-list", self._on_action),
-            ("toggle-menu-bar", self._on_action),
             ("preview-download", self._on_preview_action),
             ("preview-open", self._on_preview_action),
             ("preview-save-as", self._on_preview_action),
@@ -467,28 +500,33 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
 
         control = self.get_control()
         if control.has_active_chat():
+            contact = control.get_contact()
+            assert contact is not None
+
             if action_name == "change-nickname":
                 app.window.activate_action("win.muc-change-nickname", None)
                 return None
 
             if action_name == "change-subject":
-                open_window("GroupchatDetails", contact=control.contact, page="manage")
+                open_window("GroupchatDetails", contact=contact, page="manage")
                 return None
 
             if action_name == "escape":
                 if app.settings.get("escape_key_closes"):
-                    self._chat_page.remove_chat(
-                        control.contact.account, control.contact.jid
-                    )
-                    return None
+                    self._chat_page.remove_chat(contact.account, contact.jid)
+                else:
+                    workspace_id = self.get_active_workspace()
+                    if workspace_id is not None:
+                        app.window.activate_workspace(workspace_id)
 
-            elif action_name == "close-chat":
-                self._chat_page.remove_chat(
-                    control.contact.account, control.contact.jid
-                )
                 return None
 
-        if action_name == "escape" and app.settings.get("escape_key_closes"):
+            elif action_name == "close-chat":
+                self._chat_page.remove_chat(contact.account, contact.jid)
+                return None
+
+        if action_name in ("escape", "close-chat"):
+            # Attempt to close Gajim window if no chat has been selected
             self.close()
 
         elif action_name == "restore-chat":
@@ -512,15 +550,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
 
         elif action_name.startswith("switch-workspace-"):
             number = int(action_name[-1]) - 1
-            self._workspace_side_bar.activate_workspace_number(number)
-
-        elif action_name == "toggle-chat-list":
-            self._toggle_chat_list()
-
-        elif action_name == "toggle-menu-bar":
-            show_menu_bar = not self.get_show_menubar()
-            app.settings.set_app_setting("show_main_menu", show_menu_bar)
-            self.set_show_menubar(show_menu_bar)
+            self._app_side_bar.activate_workspace_number(number)
 
         return None
 
@@ -586,10 +616,10 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                         return
 
                     log.exception(e)
-                    SimpleDialog(
+                    InformationAlertDialog(
                         _("Could Not Save File"),
                         _("Could not save file to selected directory."),
-                        transient_for=self,
+                        parent=self,
                     )
                     return
 
@@ -608,7 +638,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                     target_path = target_path.with_suffix(orig_ext)
                 dirname = target_path.parent
                 if not os.access(dirname, os.W_OK):
-                    SimpleDialog(
+                    InformationAlertDialog(
                         _("Directory Not Writable"),
                         _(
                             'Directory "%s" is not writable. '
@@ -616,21 +646,21 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                             "create files in this directory."
                         )
                         % dirname,
-                        transient_for=self,
+                        parent=self,
                     )
                     return
 
                 try:
                     shutil.copyfile(preview.orig_path, target_path)
-                except PermissionError as e:
-                    SimpleDialog(
+                except Exception as e:
+                    InformationAlertDialog(
                         _("Could Not Save File"),
                         _(
-                            "You do not have permissions for this directory.\n"
+                            "There was an error while trying to save the file.\n"
                             "Error: %s."
                         )
                         % e,
-                        transient_for=self,
+                        parent=self,
                     )
                     return
 
@@ -673,20 +703,6 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             else:
                 open_uri(preview.uri)
 
-    def _toggle_chat_list(self) -> None:
-        chat_list_stack = self._chat_page.get_chat_list_stack()
-        chat_list = chat_list_stack.get_current_chat_list()
-        if chat_list is not None:
-            if chat_list.is_visible():
-                self._ui.toggle_chat_list_button.set_tooltip_text(_("Show chat list"))
-                self._ui.toggle_chat_list_icon.set_from_icon_name("go-next-symbolic")
-            else:
-                self._ui.toggle_chat_list_button.set_tooltip_text(_("Hide chat list"))
-                self._ui.toggle_chat_list_icon.set_from_icon_name(
-                    "go-previous-symbolic"
-                )
-        self._chat_page.toggle_chat_list()
-
     def _on_copy_message(self, _action: Gio.SimpleAction, param: GLib.Variant) -> None:
 
         self.get_clipboard().set(param.get_string())
@@ -707,7 +723,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         self, _action: Gio.SimpleAction, params: OccupantParam
     ) -> None:
 
-        def _on_confirmation() -> None:
+        def _on_response() -> None:
             client = app.get_client(params.account)
             client.get_module("MucBlocking").set_block_occupants(
                 params.jid, [params.occupant_id], True
@@ -727,14 +743,11 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             client.get_module("VCardAvatars").invalidate_cache(participant.jid)
             participant.update_avatar()
 
-        ConfirmationDialog(
+        ConfirmationAlertDialog(
             _("Block Participant?"),
             _("Do you want to block %(name)s?") % {"name": params.resource},
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make("OK", text=_("_Block"), callback=_on_confirmation),
-            ],
-            transient_for=app.window,
+            confirm_label=_("_Block"),
+            callback=_on_response,
         )
 
     @actionmethod
@@ -742,20 +755,17 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         self, _action: Gio.SimpleAction, params: OccupantParam
     ) -> None:
 
-        def _on_confirmation() -> None:
+        def _on_response() -> None:
             client = app.get_client(params.account)
             client.get_module("MucBlocking").set_block_occupants(
                 params.jid, [params.occupant_id], False
             )
 
-        ConfirmationDialog(
+        ConfirmationAlertDialog(
             _("Unblock Participant?"),
             _("Do you want to unblock %(name)s?") % {"name": params.resource},
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make("OK", text=_("_Unblock"), callback=_on_confirmation),
-            ],
-            transient_for=app.window,
+            confirm_label=_("_Unblock"),
+            callback=_on_response,
         )
 
     @actionmethod
@@ -763,24 +773,22 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         self, _action: Gio.SimpleAction, params: RetractMessageParam
     ) -> None:
 
-        def _on_retract() -> None:
+        def _on_response() -> None:
             client = app.get_client(params.account)
             contact = client.get_module("Contacts").get_contact(params.jid)
             assert not isinstance(contact, ResourceContact)
             client.get_module("Retraction").send_retraction(contact, params.retract_ids)
 
-        ConfirmationDialog(
+        ConfirmationAlertDialog(
             _("Retract Message?"),
             _(
                 "Do you want to retract this message?\n"
                 "Please note that retracting a message does not guarantee that your "
                 "provider or your contact’s device will remove it."
             ),
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make("Remove", text=_("_Retract"), callback=_on_retract),
-            ],
-            transient_for=app.window,
+            confirm_label=_("_Retract"),
+            appearance="destructive",
+            callback=_on_response,
         )
 
     @actionmethod
@@ -788,21 +796,19 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         self, _action: Gio.SimpleAction, params: ModerateMessageParam
     ) -> None:
 
-        def _on_moderate(reason: str) -> None:
+        def _on_response(reason: str) -> None:
             client = app.get_client(params.account)
             client.get_module("MUC").moderate_messages(
                 params.namespace, params.jid, params.stanza_ids, reason or None
             )
 
-        InputDialog(
+        ConfirmationAlertDialog(
             _("Moderate Message?"),
             _("Why do you want to moderate this message?"),
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make("Remove", text=_("_Moderate"), callback=_on_moderate),
-            ],
-            input_str=_("Spam"),
-            transient_for=app.window,
+            confirm_label=_("_Moderate"),
+            appearance="destructive",
+            extra_widget=DialogEntry(text=_("Spam")),
+            callback=_on_response,
         )
 
     @actionmethod
@@ -813,18 +819,18 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             params.account, params.jid, params.occupant_id
         )
         if stanza_ids is None:
-            SimpleDialog(
+            InformationAlertDialog(
                 _("No Messages Found"),
                 _("Could not find any messages for this participant."),
             )
             return
 
-        def _on_moderate(reason: str) -> None:
+        def _on_response(reason: str) -> None:
             client = app.get_client(params.account)
             groupchat_contact = client.get_module("Contacts").get_contact(params.jid)
             assert isinstance(groupchat_contact, GroupchatContact)
             if not groupchat_contact.is_joined:
-                SimpleDialog(
+                InformationAlertDialog(
                     _("Not Joined"), _("You are currently not joined this group chat")
                 )
                 return
@@ -834,19 +840,17 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                 params.namespace, params.jid, stanza_ids, reason or None
             )
 
-        InputDialog(
+        ConfirmationAlertDialog(
             _("Moderate Messages?"),
             _(
                 "%(count)s messages from %(participant)s will be moderated.\n"
                 "Why do you want to moderate these messages?"
             )
             % {"count": len(stanza_ids), "participant": params.nickname},
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make("Remove", text=_("_Moderate"), callback=_on_moderate),
-            ],
-            input_str=_("Spam"),
-            transient_for=app.window,
+            confirm_label=_("_Moderate"),
+            appearance="destructive",
+            extra_widget=DialogEntry(text=_("Spam")),
+            callback=_on_response,
         )
 
     @actionmethod
@@ -854,7 +858,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         self, _action: Gio.SimpleAction, params: DeleteMessageParam
     ) -> None:
 
-        def _on_delete() -> None:
+        def _on_response() -> None:
             app.storage.archive.delete_message(params.pk)
             app.ged.raise_event(
                 events.MessageDeleted(
@@ -862,14 +866,12 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                 )
             )
 
-        ConfirmationDialog(
+        ConfirmationAlertDialog(
             _("Delete Message Locally?"),
             _("This message will be deleted from your local chat history"),
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make("Delete", callback=_on_delete),
-            ],
-            transient_for=app.window,
+            confirm_label=_("_Delete"),
+            appearance="destructive",
+            callback=_on_response,
         )
 
     def _on_handle_uri(self, _action: Gio.SimpleAction, param: GLib.Variant) -> None:
@@ -926,13 +928,18 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             return
 
         if self.is_active():
-            client = app.get_client(control.contact.account)
+            contact = control.get_contact()
+            assert contact is not None
+            client = app.get_client(contact.account)
             chat_stack = self._chat_page.get_chat_stack()
             msg_action_box = chat_stack.get_message_action_box()
             client.get_module("Chatstate").set_mouse_activity(
-                control.contact, msg_action_box.msg_textview.has_text
+                contact, msg_action_box.msg_textview.has_text
             )
 
+    def _on_chat_selected(self, *args: Any) -> None:
+        self._app_side_bar.select_chat()
+
     def _on_close_request(self, _widget: Gtk.ApplicationWindow) -> int:
         if app.settings.get("confirm_on_window_delete"):
             open_window("QuitDialog")
@@ -968,13 +975,11 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             chat_list_stack.set_chat_unread_count(chat.account, chat.jid, chat.count)
 
     def show_account_page(self, account: str) -> None:
-        self._activity_side_bar.unselect()
-        self._workspace_side_bar.unselect_all()
-        self._account_side_bar.select()
+        self._app_side_bar.show_account_page()
         self._main_stack.show_account(account)
 
     def get_active_workspace(self) -> str | None:
-        return self._workspace_side_bar.get_active_workspace()
+        return self._app_side_bar.get_active_workspace()
 
     def is_chat_active(self, account: str, jid: JID) -> bool:
         if not self.is_active():
@@ -1001,10 +1006,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                     else:
                         row.remove_css_class("dnd-target-chatlist")
 
-        if highlight:
-            self._workspace_side_bar.add_css_class("dnd-target")
-        else:
-            self._workspace_side_bar.remove_css_class("dnd-target")
+        self._app_side_bar.highlight_dnd_targets(highlight)
 
     def _add_workspace(self, _action: Gio.SimpleAction, param: GLib.Variant) -> None:
 
@@ -1019,12 +1021,12 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         if workspace_id is None:
             workspace_id = app.settings.add_workspace(_("My Workspace"))
 
-        self._workspace_side_bar.add_workspace(workspace_id)
+        self._app_side_bar.add_workspace(workspace_id)
         self._chat_page.add_chat_list(workspace_id)
 
         if self._startup_finished and switch:
             self.activate_workspace(workspace_id)
-            self._workspace_side_bar.store_workspace_order()
+            self._app_side_bar.store_workspace_order()
 
         return workspace_id
 
@@ -1053,9 +1055,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         open_chats = chat_list.get_open_chats()
 
         def _continue_removing_workspace():
-            new_workspace_id = self._workspace_side_bar.get_other_workspace(
-                workspace_id
-            )
+            new_workspace_id = self._app_side_bar.get_other_workspace(workspace_id)
             if new_workspace_id is None:
                 log.warning("No other workspaces found")
                 return
@@ -1072,21 +1072,20 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             if was_active:
                 self.activate_workspace(new_workspace_id)
 
-            self._workspace_side_bar.remove_workspace(workspace_id)
+            self._app_side_bar.remove_workspace(workspace_id)
             self._chat_page.remove_chat_list(workspace_id)
             app.settings.remove_workspace(workspace_id)
 
         if open_chats:
-            ConfirmationDialog(
+            ConfirmationAlertDialog(
                 _("Remove Workspace?"),
                 _(
                     "This workspace contains chats. All chats will be moved to "
                     "the next workspace. Remove anyway?"
                 ),
-                [
-                    DialogButton.make("Cancel", text=_("_No")),
-                    DialogButton.make("Remove", callback=_continue_removing_workspace),
-                ],
+                confirm_label=_("_Remove"),
+                appearance="destructive",
+                callback=_continue_removing_workspace,
             )
             return
 
@@ -1102,21 +1101,14 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             self.activate_workspace(workspace_id)
 
     def activate_workspace(self, workspace_id: str) -> None:
-        self._activity_side_bar.unselect()
-        self._account_side_bar.unselect()
+        self._app_side_bar.activate_workspace(workspace_id)
         self._main_stack.show_chats(workspace_id)
-        self._workspace_side_bar.activate_workspace(workspace_id)
 
-        # Show chatlist if it is hidden
-        chat_list_stack = self._chat_page.get_chat_list_stack()
-        chat_list = chat_list_stack.get_current_chat_list()
-        if chat_list is not None:
-            if not chat_list.is_visible():
-                self._toggle_chat_list()
+        self.set_action_state("chat-list-visible", True)
 
     def update_workspace(self, workspace_id: str) -> None:
         self._chat_page.update_workspace(workspace_id)
-        self._workspace_side_bar.update_avatar(workspace_id)
+        self._app_side_bar.update_workspace(workspace_id)
 
     def get_chat_list(self, workspace_id: str) -> ChatList:
         chat_list_stack = self._chat_page.get_chat_list_stack()
@@ -1141,7 +1133,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         workspace_id = self.get_active_workspace()
         if workspace_id is not None:
             return workspace_id
-        return self._workspace_side_bar.get_first_workspace()
+        return self._app_side_bar.get_first_workspace()
 
     def _add_group_chat(self, _action: Gio.SimpleAction, param: GLib.Variant) -> None:
 
@@ -1188,8 +1180,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             chat_list.clear_chat_list_row(account, jid)
 
     def select_chat(self, account: str, jid: JID) -> None:
-        self._activity_side_bar.unselect()
-        self._account_side_bar.unselect()
+        self._app_side_bar.select_chat()
         self._main_stack.show_chat_page()
         self._chat_page.select_chat(account, jid)
 
@@ -1208,9 +1199,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             chat_list.select_chat_number(number)
 
     def show_activity_page(self, context_id: str | None = None) -> None:
-        self._account_side_bar.unselect()
-        self._workspace_side_bar.unselect_all()
-        self._activity_side_bar.select()
+        self._app_side_bar.show_activity_page()
         self._main_stack.show_activity_page(context_id)
 
     def get_control(self) -> ChatControl:
@@ -1300,8 +1289,11 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         if not control.has_active_chat():
             return
 
+        contact = control.get_contact()
+        assert contact is not None
+
         if control.view_is_at_bottom():
-            self.mark_as_read(control.contact.account, control.contact.jid)
+            self.mark_as_read(contact.account, contact.jid)
 
     def get_preferred_ft_method(self, contact: types.ChatContactT) -> str | None:
 
@@ -1371,32 +1363,31 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             return
 
         # TODO: Keep "confirm_block" setting?
-        def _block_contact(report: BlockingReportValues | None = None) -> None:
+        def _on_response(response_id: str) -> None:
+            if response_id not in ("report", "block"):
+                return
+            report = "spam" if response_id == "report" else None
             client.get_module("Blocking").block([contact.jid], report)
             self._chat_page.remove_chat(account, contact.jid)
 
-        ConfirmationDialog(
+        AlertDialog(
             _("Block Contact?"),
             _(
                 "You will appear offline for this contact and you "
                 "will not receive further messages."
             ),
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make(
-                    "OK",
-                    text=_("_Report Spam"),
-                    callback=_block_contact,
-                    kwargs={"report": "spam"},
-                ),
-                DialogButton.make("Remove", text=_("_Block"), callback=_block_contact),
+            responses=[
+                CancelDialogResponse(),
+                DialogResponse("report", _("_Report Spam")),
+                DialogResponse("block", _("_Block")),
             ],
+            callback=_on_response,
         )
 
     def remove_contact(self, account: str, jid: JID) -> None:
         client = app.get_client(account)
 
-        def _remove_contact():
+        def _on_response() -> None:
             client.get_module("Roster").delete_item(jid)
 
         contact = client.get_module("Contacts").get_contact(jid)
@@ -1407,13 +1398,12 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             "You are about to remove %(name)s (%(jid)s) from your contact list."
         ) % {"name": contact.name, "jid": jid}
 
-        ConfirmationDialog(
+        ConfirmationAlertDialog(
             _("Remove From Contact List?"),
             sec_text,
-            [
-                DialogButton.make("Cancel"),
-                DialogButton.make("Remove", callback=_remove_contact),
-            ],
+            confirm_label=_("_Remove"),
+            appearance="destructive",
+            callback=_on_response,
         )
 
     @staticmethod
@@ -1431,7 +1421,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             self.add_workspace(workspace_id)
             self._chat_page.load_workspace_chats(workspace_id)
 
-        workspace_id = self._workspace_side_bar.get_first_workspace()
+        workspace_id = self._app_side_bar.get_first_workspace()
         self.activate_workspace(workspace_id)
 
         self._set_startup_finished()
